% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/procmod_frame.R
\name{procmod.frame}
\alias{procmod.frame}
\alias{is.procmod.frame}
\alias{as.procmod.frame}
\title{The procmod.frame data structure.}
\usage{
procmod.frame(..., row.names = NULL, check.rows = FALSE,
  check.names = TRUE, reorder.rows = FALSE, contrasts.arg = NULL)

is.procmod.frame(x)

as.procmod.frame(data, ...)
}
\description{
A \code{procmod.frame} can be considered as the analog of a
\code{data.frame} for vector data. In a \code{procmod.frame}
each element, equivalent to a column in a \code{data.frame}
is a numeric matrix or a distance matrix object (\code{dist}).
Every element must describe the same number of individuals.
Therefore every numeric matrix must have the same number of row
(\code{nrow}) and every distance matrix must have the same size
(\code{attr(d,"Size")}). A \code{procmod.frame} can simultaneously
contain both types of data, numeric and distance matrix.
}
\examples{
library(vegan)
data(bacteria)
data(eukaryotes)
data(soil)

dataset <- procmod.frame(euk = vegdist(decostand(eukaryotes,
                                                 method = "hellinger"),
                                       method = "euclidean"),
                         bac = vegdist(decostand(bacteria,
                                                 method = "hellinger"),
                                       method = "euclidean"),
                         soil = scale(soil,
                                      center = TRUE,
                                      scale  = TRUE))
length(dataset)
nrow(dataset)
ncol(dataset)
dataset$euk

}
\author{
Eric Coissac

Christelle Gonindard-Melodelima
}
